@@ -5,6 +5,10 @@ import psycopg2
 
 from typing import Any, Dict, List, Tuple
 
+class BucketType:
+    DATA='BUCKET_DATA'
+    MODEL='BUCKET_MODEL'
+    DATASET='BUCKET_DATASET'
 
 class SimpleStorageService:
     """
@@ -15,31 +19,31 @@ class SimpleStorageService:
         bucket (str): range name of files and folder
         resource (Any): instance connected to aws to reference aws s3
     """
-    def __init__(self, bucket_internal:str=None) -> None:
+    def __init__(self) -> None:
         self._session = boto3.Session(
             aws_access_key_id=os.getenv("AWS_ACCESS_KEY_ID"),
             aws_secret_access_key=os.getenv("AWS_SECRET_ACCESS_KEY")
         )
-        self._bucket = os.getenv("BUCKET") if bucket_internal is None else bucket_internal
         self._resource = self._session.resource('s3')
 
-    def exists(self, path:str) -> bool:
+    def exists(self, path:str, bucket_name:str=BucketType.DATA) -> bool:
         """        
         Method that validates whether a file exists or not
         
         Parameters:
             path (str): remote path of the file to be published
+            bucket_name (BucketType | None): remote storage name
 
         Returns:
             bool: return whether a file exists or not
         """
         try:
-            self._resource.Object(self._bucket, path).load()
+            self._resource.Object(os.getenv(bucket_name), path).load()
             return True
         except:
             return False
 
-    def push(self, object:Any, path:str, hash:bool=False, extension:str=None) -> str:
+    def push(self, object:Any, path:str, hash:bool=False, extension:str=None, bucket_name:str=BucketType.DATA) -> str:
         """        
         Method to publish files to storage
         
@@ -48,48 +52,52 @@ class SimpleStorageService:
             path (str): remote path of the file to be published
             hash (bool | None): defines whether the new file will have a dynamic name
             extension (str | None): defines whether the new file will have a fixed extension
+            bucket_name (BucketType | None): remote storage name
 
         Returns:
             str: returns the remote path of the published file
         """
         if hash:
             path += f'/{uuid.uuid4()}.{extension}'
-        self._resource.Object(self._bucket, path).put(Body=object)
+        self._resource.Object(os.getenv(bucket_name), path).put(Body=object)
         return path
 
-    def get_bytes(self, path:str) -> Any:
+    def get_bytes(self, path:str, bucket_name:str=BucketType.DATA) -> Any:
         """        
         Method to get a byte string from a file
         
         Parameters:
             path (str): remote path of the file to be published
+            bucket_name (BucketType | None): remote storage name
 
         Returns:
             any: return the bytes of the file
         """
-        bucket = self._resource.Bucket(self._bucket)
+        bucket = self._resource.Bucket(os.getenv(bucket_name))
         return bucket.Object(path).get().get('Body').read()
 
-    def download(self, source:str, destine:str) -> None:
+    def download(self, source:str, destine:str, bucket_name:str=BucketType.DATA) -> None:
         """        
         Method to download files
         
         Parameters:
             source (str): remote path of the file to be published
             destine (str): local path to save the file
+            bucket_name (BucketType | None): remote storage name
         """
-        bucket = self._resource.Bucket(self._bucket)
+        bucket = self._resource.Bucket(os.getenv(bucket_name))
         bucket.download_file(source, destine)
 
-    def download_all(self, source:str, destine:str) -> None:
+    def download_all(self, source:str, destine:str, bucket_name:str=BucketType.DATA) -> None:
         """        
         Method to download all files
         
         Parameters:
             source (str): remote path of the file to be published
             destine (str): local path to save the file
+            bucket_name (BucketType | None): remote storage name
         """
-        bucket = self._resource.Bucket(self._bucket)
+        bucket = self._resource.Bucket(os.getenv(bucket_name))
 
         for file_object in bucket.objects.filter(Prefix=source):
             local_path = os.path.join(destine, file_object.key)
